:mod:`maec.package.malware_subject` Module
==========================================

.. module:: maec.package.malware_subject

Classes
-------

.. autoclass:: MalwareSubject
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareSubjectList
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareConfigurationDetails
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareConfigurationObfuscationDetails
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareConfigurationObfuscationAlgorithm
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareConfigurationStorageDetails
	:show-inheritance:
	:members:

.. autoclass:: MalwareBinaryConfigurationStorageDetails
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareConfigurationParameter
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareDevelopmentEnvironment
	:show-inheritance:
	:members:

.. autoclass:: FindingsBundleList
	:show-inheritance:
	:members:
  
.. autoclass:: MetaAnalysis
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareSubjectRelationshipList
	:show-inheritance:
	:members:
  
.. autoclass:: MalwareSubjectRelationship
	:show-inheritance:
	:members:
  
.. autoclass:: Analyses
	:show-inheritance:
	:members:
  
.. autoclass:: MinorVariants
	:show-inheritance:
	:members:
